import{s as Re,c as Ne,o as qe,r as re,b as Le,n as Z,d as ie}from"../chunks/scheduler.D08FylXR.js";import{S as Se,i as je,s as B,e as g,o as se,p as Be,d as _,f as U,c as w,q as ce,a as P,r as f,g as j,h as p,u as Q,n as v,l as V,m as ee,v as De,t as X,b as Y,j as ue,w as M,x as W,y as fe,z as G,k as le,A as J,B as Ue}from"../chunks/index.bOCONIGK.js";import{h as _e,u as Qe}from"../chunks/await_block.BkBWoonF.js";import{e as ae,F as K,f as Pe,a as Fe,b as Ie,c as ze,p as He,s as Me,d as We,g as Te,h as Ve,i as Ge,j as de,k as he,l as me,m as Je,n as Ce}from"../chunks/mopidyTools.ClDgnaVf.js";import{c as Ke}from"../chunks/clickOutside.BxFJ2b6i.js";function pe(s,e,l){const t=s.slice();return t[29]=e[l],t[31]=l,t}function ke(s,e,l){const t=s.slice();return t[33]=e[l],t[31]=l,t}function ve(s){let e,l,t=s[33].name+"",r,n,a,m;function o(){return s[15](s[33],s[31])}return{c(){e=g("li"),l=g("a"),r=X(t),n=B(),this.h()},l(i){e=w(i,"LI",{class:!0});var u=P(e);l=w(u,"A",{href:!0,class:!0});var h=P(l);r=Y(h,t),h.forEach(_),n=U(u),u.forEach(_),this.h()},h(){f(l,"href",null),f(l,"class","svelte-6ensgs"),f(e,"class","svelte-6ensgs")},m(i,u){j(i,e,u),p(e,l),p(l,r),p(e,n),a||(m=Q(l,"click",o),a=!0)},p(i,u){s=i,u[0]&1&&t!==(t=s[33].name+"")&&ue(r,t)},d(i){i&&_(e),a=!1,m()}}}function be(s){let e,l,t,r,n,a,m,o,i,u,h,y,$,C,b,k,E,A,T,S,F,q;const R=[Ye,Xe],D=[];function N(c,O){return c[4]?0:1}return r=N(s),n=D[r]=R[r](s),u=new K({props:{icon:Pe,class:"icon is-small"}}),C=new K({props:{icon:Fe,class:"icon is-small"}}),A=new K({props:{icon:Ie,class:"icon is-small"}}),{c(){e=g("div"),l=g("div"),t=g("div"),n.c(),a=B(),m=g("div"),o=g("div"),i=g("a"),M(u.$$.fragment),h=X(`  
            Play now`),y=B(),$=g("a"),M(C.$$.fragment),b=X(`  
            Play shuffle`),k=B(),E=g("a"),M(A.$$.fragment),T=X(`  
            Add to queue`),this.h()},l(c){e=w(c,"DIV",{class:!0});var O=P(e);l=w(O,"DIV",{class:!0});var I=P(l);t=w(I,"DIV",{class:!0,role:!0,tabindex:!0});var x=P(t);n.l(x),x.forEach(_),a=U(I),m=w(I,"DIV",{class:!0,id:!0,role:!0});var te=P(m);o=w(te,"DIV",{class:!0});var H=P(o);i=w(H,"A",{href:!0,class:!0});var d=P(i);W(u.$$.fragment,d),h=Y(d,`  
            Play now`),d.forEach(_),y=U(H),$=w(H,"A",{href:!0,class:!0});var L=P($);W(C.$$.fragment,L),b=Y(L,`  
            Play shuffle`),L.forEach(_),k=U(H),E=w(H,"A",{href:!0,class:!0});var z=P(E);W(A.$$.fragment,z),T=Y(z,`  
            Add to queue`),z.forEach(_),H.forEach(_),te.forEach(_),I.forEach(_),O.forEach(_),this.h()},h(){f(t,"class","dropdown-trigger"),f(t,"role","button"),f(t,"tabindex","0"),f(i,"href",null),f(i,"class","dropdown-item"),f($,"href",null),f($,"class","dropdown-item"),f(E,"href",null),f(E,"class","dropdown-item"),f(o,"class","dropdown-content"),f(m,"class","dropdown-menu"),f(m,"id","dropdown-menu"),f(m,"role","menu"),f(l,"class","dropdown is-right"),fe(l,"is-active",s[4]),f(e,"class","column is-narrow")},m(c,O){j(c,e,O),p(e,l),p(l,t),D[r].m(t,null),p(l,a),p(l,m),p(m,o),p(o,i),G(u,i,null),p(i,h),p(o,y),p(o,$),G(C,$,null),p($,b),p(o,k),p(o,E),G(A,E,null),p(E,T),S=!0,F||(q=[Q(t,"click",s[16]),Q(t,"keypress",s[17]),Q(i,"click",s[18]),Q($,"click",s[19]),Q(E,"click",s[20])],F=!0)},p(c,O){let I=r;r=N(c),r!==I&&(le(),V(D[I],1,1,()=>{D[I]=null}),ee(),n=D[r],n||(n=D[r]=R[r](c),n.c()),v(n,1),n.m(t,null)),(!S||O[0]&16)&&fe(l,"is-active",c[4])},i(c){S||(v(n),v(u.$$.fragment,c),v(C.$$.fragment,c),v(A.$$.fragment,c),S=!0)},o(c){V(n),V(u.$$.fragment,c),V(C.$$.fragment,c),V(A.$$.fragment,c),S=!1},d(c){c&&_(e),D[r].d(),J(u),J(C),J(A),F=!1,re(q)}}}function Xe(s){let e,l,t;return l=new K({props:{icon:Te,class:"icon","aria-haspopup":"true","aria-controls":"dropdown-menu"}}),{c(){e=g("a"),M(l.$$.fragment),this.h()},l(r){e=w(r,"A",{href:!0,class:!0});var n=P(e);W(l.$$.fragment,n),n.forEach(_),this.h()},h(){f(e,"href",null),f(e,"class","button")},m(r,n){j(r,e,n),G(l,e,null),t=!0},i(r){t||(v(l.$$.fragment,r),t=!0)},o(r){V(l.$$.fragment,r),t=!1},d(r){r&&_(e),J(l)}}}function Ye(s){let e,l,t;return l=new K({props:{icon:Ve,class:"icon","aria-haspopup":"true","aria-controls":"dropdown-menu"}}),{c(){e=g("a"),M(l.$$.fragment),this.h()},l(r){e=w(r,"A",{href:!0,class:!0});var n=P(e);W(l.$$.fragment,n),n.forEach(_),this.h()},h(){f(e,"href",null),f(e,"class","button")},m(r,n){j(r,e,n),G(l,e,null),t=!0},i(r){t||(v(l.$$.fragment,r),t=!0)},o(r){V(l.$$.fragment,r),t=!1},d(r){r&&_(e),J(l)}}}function ge(s){let e,l,t,r={ctx:s,current:null,token:null,hasCatch:!0,pending:el,then:xe,catch:Ze,error:32,blocks:[,,,]};return _e(l=s[2],r),{c(){e=g("div"),r.block.c(),this.h()},l(n){e=w(n,"DIV",{class:!0});var a=P(e);r.block.l(a),a.forEach(_),this.h()},h(){f(e,"class","list is-hoverable")},m(n,a){j(n,e,a),r.block.m(e,r.anchor=null),r.mount=()=>e,r.anchor=null,t=!0},p(n,a){s=n,r.ctx=s,a[0]&4&&l!==(l=s[2])&&_e(l,r)||Qe(r,s,a)},i(n){t||(v(r.block),t=!0)},o(n){for(let a=0;a<3;a+=1){const m=r.blocks[a];V(m)}t=!1},d(n){n&&_(e),r.block.d(),r.token=null,r=null}}}function Ze(s){let e,l=s[32].message+"",t;return{c(){e=g("p"),t=X(l),this.h()},l(r){e=w(r,"P",{class:!0,style:!0});var n=P(e);t=Y(n,l),n.forEach(_),this.h()},h(){f(e,"class","list-item"),Ue(e,"color","red")},m(r,n){j(r,e,n),p(e,t)},p(r,n){n[0]&4&&l!==(l=r[32].message+"")&&ue(t,l)},i:Z,o:Z,d(r){r&&_(e)}}}function xe(s){return{c:Z,l:Z,m:Z,p:Z,i:Z,o:Z,d:Z}}function el(s){let e,l,t,r;const n=[tl,ll],a=[];function m(o,i){return o[5]?0:1}return e=m(s),l=a[e]=n[e](s),{c(){l.c(),t=se()},l(o){l.l(o),t=se()},m(o,i){a[e].m(o,i),j(o,t,i),r=!0},p(o,i){let u=e;e=m(o),e!==u&&(le(),V(a[u],1,1,()=>{a[u]=null}),ee(),l=a[e],l||(l=a[e]=n[e](o),l.c()),v(l,1),l.m(t.parentNode,t))},i(o){r||(v(l),r=!0)},o(o){V(l),r=!1},d(o){o&&_(t),a[e].d(o)}}}function ll(s){let e,l,t,r;return t=new K({props:{icon:Ce,class:"icon is-24",spin:!0}}),{c(){e=g("p"),l=X(`Connecting to mopidy     
          `),M(t.$$.fragment),this.h()},l(n){e=w(n,"P",{class:!0});var a=P(e);l=Y(a,`Connecting to mopidy     
          `),W(t.$$.fragment,a),a.forEach(_),this.h()},h(){f(e,"class","list-item")},m(n,a){j(n,e,a),p(e,l),G(t,e,null),r=!0},i(n){r||(v(t.$$.fragment,n),r=!0)},o(n){V(t.$$.fragment,n),r=!1},d(n){n&&_(e),J(t)}}}function tl(s){let e,l,t,r;return t=new K({props:{icon:Ce,spin:!0,class:"icon"}}),{c(){e=g("p"),l=X(`Loading sources    
          `),M(t.$$.fragment),this.h()},l(n){e=w(n,"P",{class:!0});var a=P(e);l=Y(a,`Loading sources    
          `),W(t.$$.fragment,a),a.forEach(_),this.h()},h(){f(e,"class","list-item")},m(n,a){j(n,e,a),p(e,l),G(t,e,null),r=!0},i(n){r||(v(t.$$.fragment,n),r=!0)},o(n){V(t.$$.fragment,n),r=!1},d(n){n&&_(e),J(t)}}}function we(s){let e,l,t,r,n=ae(s[1]),a=[];for(let i=0;i<n.length;i+=1)a[i]=Ae(pe(s,n,i));const m=i=>V(a[i],1,1,()=>{a[i]=null});let o=null;return n.length||(o=ye()),{c(){e=g("div");for(let i=0;i<a.length;i+=1)a[i].c();o&&o.c(),this.h()},l(i){e=w(i,"DIV",{class:!0});var u=P(e);for(let h=0;h<a.length;h+=1)a[h].l(u);o&&o.l(u),u.forEach(_),this.h()},h(){f(e,"class","list is-hoverable")},m(i,u){j(i,e,u);for(let h=0;h<a.length;h+=1)a[h]&&a[h].m(e,null);o&&o.m(e,null),l=!0,t||(r=[Le(Ke.call(null,e)),Q(e,"click_outside",s[25])],t=!0)},p(i,u){if(u[0]&846){n=ae(i[1]);let h;for(h=0;h<n.length;h+=1){const y=pe(i,n,h);a[h]?(a[h].p(y,u),v(a[h],1)):(a[h]=Ae(y),a[h].c(),v(a[h],1),a[h].m(e,null))}for(le(),h=n.length;h<a.length;h+=1)m(h);ee(),!n.length&&o?o.p(i,u):n.length?o&&(o.d(1),o=null):(o=ye(),o.c(),o.m(e,null))}},i(i){if(!l){for(let u=0;u<n.length;u+=1)v(a[u]);l=!0}},o(i){a=a.filter(Boolean);for(let u=0;u<a.length;u+=1)V(a[u]);l=!1},d(i){i&&_(e),De(a,i),o&&o.d(),t=!1,re(r)}}}function ye(s){let e,l=`no results
      `;return{c(){e=g("a"),e.textContent=l,this.h()},l(t){e=w(t,"A",{href:!0,class:!0,"data-svelte-h":!0}),ce(e)!=="svelte-1bdvafr"&&(e.textContent=l),this.h()},h(){f(e,"href",null),f(e,"class","list-item")},m(t,r){j(t,e,r)},p:Z,d(t){t&&_(e)}}}function $e(s){let e,l,t,r,n,a;const m=[nl,rl],o=[];function i(y,$){return y[3]==y[31]?0:1}l=i(s),t=o[l]=m[l](s);function u(){return s[23](s[31])}function h(){return s[24](s[31])}return{c(){e=g("div"),t.c(),this.h()},l(y){e=w(y,"DIV",{class:!0,role:!0,tabindex:!0});var $=P(e);t.l($),$.forEach(_),this.h()},h(){f(e,"class","column is-narrow"),f(e,"role","button"),f(e,"tabindex","0")},m(y,$){j(y,e,$),o[l].m(e,null),r=!0,n||(a=[Q(e,"click",u),Q(e,"keypress",h)],n=!0)},p(y,$){s=y;let C=l;l=i(s),l!==C&&(le(),V(o[C],1,1,()=>{o[C]=null}),ee(),t=o[l],t||(t=o[l]=m[l](s),t.c()),v(t,1),t.m(e,null))},i(y){r||(v(t),r=!0)},o(y){V(t),r=!1},d(y){y&&_(e),o[l].d(),n=!1,re(a)}}}function rl(s){let e,l;return e=new K({props:{icon:Te,class:"icon","aria-haspopup":"true","aria-controls":"dropdown-menu"}}),{c(){M(e.$$.fragment)},l(t){W(e.$$.fragment,t)},m(t,r){G(e,t,r),l=!0},i(t){l||(v(e.$$.fragment,t),l=!0)},o(t){V(e.$$.fragment,t),l=!1},d(t){J(e,t)}}}function nl(s){let e,l;return e=new K({props:{icon:Ve,class:"icon","aria-haspopup":"true","aria-controls":"dropdown-menu"}}),{c(){M(e.$$.fragment)},l(t){W(e.$$.fragment,t)},m(t,r){G(e,t,r),l=!0},i(t){l||(v(e.$$.fragment,t),l=!0)},o(t){V(e.$$.fragment,t),l=!1},d(t){J(e,t)}}}function Ee(s){let e,l,t,r,n,a,m,o,i,u,h,y,$,C,b,k,E,A;return r=new K({props:{icon:Pe,class:"icon is-small"}}),i=new K({props:{icon:Ge,class:"icon is-small"}}),C=new K({props:{icon:Ie,class:"icon is-small"}}),{c(){e=g("div"),l=g("div"),t=g("a"),M(r.$$.fragment),n=X(` 
                    Play now`),a=B(),m=g("div"),o=g("a"),M(i.$$.fragment),u=X(` 
                    Play next`),h=B(),y=g("div"),$=g("a"),M(C.$$.fragment),b=X(` 
                    Add to queue`),this.h()},l(T){e=w(T,"DIV",{class:!0});var S=P(e);l=w(S,"DIV",{class:!0});var F=P(l);t=w(F,"A",{href:!0,class:!0});var q=P(t);W(r.$$.fragment,q),n=Y(q,` 
                    Play now`),q.forEach(_),F.forEach(_),a=U(S),m=w(S,"DIV",{class:!0});var R=P(m);o=w(R,"A",{href:!0,class:!0});var D=P(o);W(i.$$.fragment,D),u=Y(D,` 
                    Play next`),D.forEach(_),R.forEach(_),h=U(S),y=w(S,"DIV",{class:!0});var N=P(y);$=w(N,"A",{href:!0,class:!0});var c=P($);W(C.$$.fragment,c),b=Y(c,` 
                    Add to queue`),c.forEach(_),N.forEach(_),S.forEach(_),this.h()},h(){f(t,"href",null),f(t,"class","dropdown-item"),f(l,"class","list-item"),f(o,"href",null),f(o,"class","dropdown-item"),f(m,"class","list-item"),f($,"href",null),f($,"class","dropdown-item"),f(y,"class","list-item"),f(e,"class","list is-hoverable")},m(T,S){j(T,e,S),p(e,l),p(l,t),G(r,t,null),p(t,n),p(e,a),p(e,m),p(m,o),G(i,o,null),p(o,u),p(e,h),p(e,y),p(y,$),G(C,$,null),p($,b),k=!0,E||(A=[Q(t,"click",function(){ie(de(s[29].uri))&&de(s[29].uri).apply(this,arguments)}),Q(o,"click",function(){ie(he(s[29].uri))&&he(s[29].uri).apply(this,arguments)}),Q($,"click",function(){ie(me(s[29].uri))&&me(s[29].uri).apply(this,arguments)})],E=!0)},p(T,S){s=T},i(T){k||(v(r.$$.fragment,T),v(i.$$.fragment,T),v(C.$$.fragment,T),k=!0)},o(T){V(r.$$.fragment,T),V(i.$$.fragment,T),V(C.$$.fragment,T),k=!1},d(T){T&&_(e),J(r),J(i),J(C),E=!1,re(A)}}}function Ae(s){let e,l,t,r=s[29].name+"",n,a,m=s[8](s[29]),o,i,u,h,y;function $(){return s[21](s[29],s[31])}function C(){return s[22](s[29],s[31])}let b=m&&$e(s),k=s[3]==s[31]&&Ee(s);return{c(){e=g("a"),l=g("div"),t=g("div"),n=X(r),a=B(),b&&b.c(),o=B(),k&&k.c(),i=B(),this.h()},l(E){e=w(E,"A",{href:!0,class:!0});var A=P(e);l=w(A,"DIV",{class:!0});var T=P(l);t=w(T,"DIV",{class:!0,role:!0,tabindex:!0});var S=P(t);n=Y(S,r),S.forEach(_),a=U(T),b&&b.l(T),T.forEach(_),o=U(A),k&&k.l(A),i=U(A),A.forEach(_),this.h()},h(){f(t,"class","column"),f(t,"role","button"),f(t,"tabindex","0"),f(l,"class","columns is-mobile"),f(e,"href",null),f(e,"class","list-item")},m(E,A){j(E,e,A),p(e,l),p(l,t),p(t,n),p(l,a),b&&b.m(l,null),p(e,o),k&&k.m(e,null),p(e,i),u=!0,h||(y=[Q(t,"click",$),Q(t,"keypress",C)],h=!0)},p(E,A){s=E,(!u||A[0]&2)&&r!==(r=s[29].name+"")&&ue(n,r),A[0]&2&&(m=s[8](s[29])),m?b?(b.p(s,A),A[0]&2&&v(b,1)):(b=$e(s),b.c(),v(b,1),b.m(l,null)):b&&(le(),V(b,1,1,()=>{b=null}),ee()),s[3]==s[31]?k?(k.p(s,A),A[0]&8&&v(k,1)):(k=Ee(s),k.c(),v(k,1),k.m(e,i)):k&&(le(),V(k,1,1,()=>{k=null}),ee())},i(E){u||(v(b),v(k),u=!0)},o(E){V(b),V(k),u=!1},d(E){E&&_(e),b&&b.d(),k&&k.d(),h=!1,re(y)}}}function sl(s){let e,l,t="Browse",r,n,a,m,o,i,u,h="Root",y,$,C=s[1].some(s[7]),b,k,E,A,T,S,F=ae(s[0]),q=[];for(let c=0;c<F.length;c+=1)q[c]=ve(ke(s,F,c));let R=C&&be(s),D=s[2]&&ge(s),N=s[1].length>0&&we(s);return{c(){e=B(),l=g("h1"),l.textContent=t,r=B(),n=g("div"),a=g("div"),m=g("nav"),o=g("ul"),i=g("li"),u=g("a"),u.textContent=h,y=B();for(let c=0;c<q.length;c+=1)q[c].c();$=B(),R&&R.c(),b=B(),D&&D.c(),k=B(),N&&N.c(),E=se(),this.h()},l(c){Be("svelte-1n5cjn7",document.head).forEach(_),e=U(c),l=w(c,"H1",{class:!0,"data-svelte-h":!0}),ce(l)!=="svelte-1bi3tp3"&&(l.textContent=t),r=U(c),n=w(c,"DIV",{class:!0});var I=P(n);a=w(I,"DIV",{class:!0});var x=P(a);m=w(x,"NAV",{class:!0,"aria-label":!0});var te=P(m);o=w(te,"UL",{class:!0});var H=P(o);i=w(H,"LI",{class:!0});var d=P(i);u=w(d,"A",{href:!0,class:!0,"data-svelte-h":!0}),ce(u)!=="svelte-jvtsu3"&&(u.textContent=h),d.forEach(_),y=U(H);for(let L=0;L<q.length;L+=1)q[L].l(H);H.forEach(_),te.forEach(_),x.forEach(_),$=U(I),R&&R.l(I),I.forEach(_),b=U(c),D&&D.l(c),k=U(c),N&&N.l(c),E=se(),this.h()},h(){document.title="Browse",f(l,"class","title"),f(u,"href",null),f(u,"class","svelte-6ensgs"),f(i,"class","svelte-6ensgs"),f(o,"class","svelte-6ensgs"),f(m,"class","breadcrumb svelte-6ensgs"),f(m,"aria-label","breadcrumbs"),f(a,"class","column"),f(n,"class","columns is-mobile")},m(c,O){j(c,e,O),j(c,l,O),j(c,r,O),j(c,n,O),p(n,a),p(a,m),p(m,o),p(o,i),p(i,u),p(o,y);for(let I=0;I<q.length;I+=1)q[I]&&q[I].m(o,null);p(n,$),R&&R.m(n,null),j(c,b,O),D&&D.m(c,O),j(c,k,O),N&&N.m(c,O),j(c,E,O),A=!0,T||(S=Q(u,"click",s[14]),T=!0)},p(c,O){if(O[0]&69){F=ae(c[0]);let I;for(I=0;I<F.length;I+=1){const x=ke(c,F,I);q[I]?q[I].p(x,O):(q[I]=ve(x),q[I].c(),q[I].m(o,null))}for(;I<q.length;I+=1)q[I].d(1);q.length=F.length}O[0]&2&&(C=c[1].some(c[7])),C?R?(R.p(c,O),O[0]&2&&v(R,1)):(R=be(c),R.c(),v(R,1),R.m(n,null)):R&&(le(),V(R,1,1,()=>{R=null}),ee()),c[2]?D?(D.p(c,O),O[0]&4&&v(D,1)):(D=ge(c),D.c(),v(D,1),D.m(k.parentNode,k)):D&&(le(),V(D,1,1,()=>{D=null}),ee()),c[1].length>0?N?(N.p(c,O),O[0]&2&&v(N,1)):(N=we(c),N.c(),v(N,1),N.m(E.parentNode,E)):N&&(le(),V(N,1,1,()=>{N=null}),ee())},i(c){A||(v(R),v(D),v(N),A=!0)},o(c){V(R),V(D),V(N),A=!1},d(c){c&&(_(e),_(l),_(r),_(n),_(b),_(k),_(E)),De(q,c),R&&R.d(),D&&D.d(c),N&&N.d(c),T=!1,S()}}}function al(s,e,l){let t;Ne(s,Je,d=>l(26,t=d));let r=[],n=[],a,m,o=!1,i;qe(async()=>{l(2,a=u())});const u=async()=>{l(5,i=await ze()),l(1,n=await t.library.browse({uri:null}))},h=async(d,L,z)=>{if(["directory","artist","album","playlist"].indexOf(d.type)>-1){l(3,m=null);const ne=await t.library.browse({uri:d.uri});if(ne.length==0){const oe=await t.library.lookup({uris:[d.uri]});l(1,n=oe[d.uri])}else l(1,n=ne);if(z==="back"){const oe=r.indexOf(d),Oe=r.slice(0,oe+1);l(0,r=Oe)}else z==="avance"&&l(0,r=[...r,d])}else(d.type==="track"||d.__model__==="Track")&&C(L)},y=d=>["track"].indexOf(d.type)>-1||d.__model__==="Track"||d.type==="directory"&&d.uri.indexOf("file://")>-1,$=d=>["album","track","artist","playlist"].indexOf(d.type)>-1||d.__model__==="Track",C=d=>{m==d?l(3,m=null):l(3,m=d)},b=async()=>{l(1,n=await t.library.browse({uri:null})),l(0,r=[])},k=async d=>{if(d.type==="track"||d.__model__==="Track")return d.uri;if(d.type==="directory"&&d.uri.indexOf("file://")>-1){const L=await t.library.browse({uri:d.uri});return(await Promise.all(L.map(ne=>k(ne)))).flat(1)}},E=async d=>{const L=await Promise.all(d.map(z=>k(z)));He(L.flat(1)),l(4,o=!1)},A=async d=>{const L=await Promise.all(d.map(z=>k(z)));Me(null,L.flat(1)),l(4,o=!1)},T=async d=>{const L=await Promise.all(d.map(z=>k(z)));We(null,L.flat(1))};return[r,n,a,m,o,i,h,y,$,C,b,E,A,T,()=>l(2,a=b()),(d,L)=>l(2,a=h(d,L,"back")),()=>l(4,o=!o),()=>l(4,o=!o),()=>E(n),()=>A(n),()=>T(n),(d,L)=>l(2,a=h(d,L,"avance")),(d,L)=>l(2,a=h(d,L,"avance")),d=>C(d),d=>C(d),()=>l(3,m=null)]}class _l extends Se{constructor(e){super(),je(this,e,al,sl,Re,{},null,[-1,-1])}}export{_l as component};
