.fa.svelte-88c8nf{align-items:center;display:inline-flex;justify-content:center;height:1.25rem;width:1.25rem}.is-low.svelte-88c8nf{margin-bottom:-.25rem}.is-lower.svelte-88c8nf{margin-bottom:-.35rem}.is-48.svelte-88c8nf{margin-top:8px;width:48px;height:48px}.is-36.svelte-88c8nf{margin-top:4px!important;width:36px;height:36px}.is-24.svelte-88c8nf{vertical-align:-.35em;width:24px;height:24px}.is-info.svelte-88c8nf{color:#209cee}.is-small.svelte-88c8nf{height:.75rem!important;width:.75rem!important}.is-small.is-low.svelte-88c8nf{margin-bottom:-.15rem!important}@-webkit-keyframes svelte-88c8nf-spinner-spin{0%{transform:rotate(0)}to{transform:rotate(360deg)}}@-moz-keyframes svelte-88c8nf-spinner-spin{0%{transform:rotate(0)}to{transform:rotate(360deg)}}@-o-keyframes svelte-88c8nf-spinner-spin{0%{transform:rotate(0)}to{transform:rotate(360deg)}}@-ms-keyframes svelte-88c8nf-spinner-spin{0%{transform:rotate(0)}to{transform:rotate(360deg)}}@keyframes svelte-88c8nf-spinner-spin{0%{transform:rotate(0)}to{transform:rotate(360deg)}}.spin.svelte-88c8nf{-webkit-animation:svelte-88c8nf-spinner-spin 1s steps(8) infinite;-moz-animation:svelte-88c8nf-spinner-spin 1s steps(8) infinite;-o-animation:svelte-88c8nf-spinner-spin 1s steps(8) infinite;animation:svelte-88c8nf-spinner-spin 1s steps(8) infinite}
