.input.svelte-ojelhk.svelte-ojelhk{-moz-appearance:none;-webkit-appearance:none;align-items:center;border:1px solid transparent;border-radius:4px;box-shadow:none;display:inline-flex;font-size:1rem;height:2.5em;justify-content:flex-start;line-height:1.5;padding-bottom:calc(.5em - 1px);padding-left:calc(.75em - 1px);padding-right:calc(.75em - 1px);padding-top:calc(.5em - 1px);position:relative;vertical-align:top}.input.svelte-ojelhk.svelte-ojelhk{background-color:#fff;border-color:#dbdbdb;border-radius:4px;color:#363636}.input.svelte-ojelhk.svelte-ojelhk::-moz-placeholder{color:#3636364d}.input.svelte-ojelhk.svelte-ojelhk::-webkit-input-placeholder{color:#3636364d}.input.svelte-ojelhk.svelte-ojelhk:-moz-placeholder{color:#3636364d}.input.svelte-ojelhk.svelte-ojelhk:-ms-input-placeholder{color:#3636364d}.input.svelte-ojelhk.svelte-ojelhk:hover{border-color:#b5b5b5}.input.svelte-ojelhk.svelte-ojelhk:focus{border-color:#3273dc;box-shadow:0 0 0 .125em #3273dc40}.input.svelte-ojelhk.svelte-ojelhk{box-shadow:inset 0 .0625em .125em #0a0a0a0d;max-width:100%;width:100%}.hovering.svelte-ojelhk.svelte-ojelhk{border:1px solid orange}.hovering.svelte-ojelhk .svelte-ojelhk{pointer-events:none}.menu.svelte-ojelhk.svelte-ojelhk{font-size:1rem}.menu-list.svelte-ojelhk.svelte-ojelhk{line-height:1.25}.menu-list.svelte-ojelhk a.svelte-ojelhk{border-radius:2px;color:#4a4a4a;display:block;padding:.5em .75em}.menu-list.svelte-ojelhk a.svelte-ojelhk:hover{background-color:#f5f5f5;color:#363636}.menu-label.svelte-ojelhk.svelte-ojelhk{color:#7a7a7a;font-size:.75em;letter-spacing:.1em;text-transform:uppercase}.menu-label.svelte-ojelhk.svelte-ojelhk:not(:first-child){margin-top:1em}.menu-label.svelte-ojelhk.svelte-ojelhk:not(:last-child){margin-bottom:1em}
