function g(){}const A=t=>t;function w(t,n){for(const e in n)t[e]=n[e];return t}function B(t){return!!t&&(typeof t=="object"||typeof t=="function")&&typeof t.then=="function"}function j(t){return t()}function C(){return Object.create(null)}function E(t){t.forEach(j)}function q(t){return typeof t=="function"}function D(t,n){return t!=t?n==n:t!==n||t&&typeof t=="object"||typeof t=="function"}let f;function P(t,n){return t===n?!0:(f||(f=document.createElement("a")),f.href=n,t===f.href)}function S(t){return Object.keys(t).length===0}function O(t,...n){if(t==null){for(const r of n)r(void 0);return g}const e=t.subscribe(...n);return e.unsubscribe?()=>e.unsubscribe():e}function U(t,n,e){t.$$.on_destroy.push(O(n,e))}function G(t,n,e,r){if(t){const o=m(t,n,e,r);return t[0](o)}}function m(t,n,e,r){return t[1]&&r?w(e.ctx.slice(),t[1](r(n))):e.ctx}function H(t,n,e,r){if(t[2]&&r){const o=t[2](r(e));if(n.dirty===void 0)return o;if(typeof o=="object"){const a=[],_=Math.max(n.dirty.length,o.length);for(let u=0;u<_;u+=1)a[u]=n.dirty[u]|o[u];return a}return n.dirty|o}return n.dirty}function I(t,n,e,r,o,a){if(o){const _=m(n,e,r,a);t.p(_,o)}}function J(t){if(t.ctx.length>32){const n=[],e=t.ctx.length/32;for(let r=0;r<e;r++)n[r]=-1;return n}return-1}function K(t){const n={};for(const e in t)e[0]!=="$"&&(n[e]=t[e]);return n}function L(t){return t??""}function N(t,n,e){return t.set(e),n}function Q(t){return t&&q(t.destroy)?t.destroy:g}let l;function d(t){l=t}function x(){if(!l)throw new Error("Function called outside component initialization");return l}function R(t){x().$$.on_mount.push(t)}function T(t){x().$$.after_update.push(t)}const i=[],y=[];let s=[];const b=[],k=Promise.resolve();let p=!1;function z(){p||(p=!0,k.then(M))}function V(){return z(),k}function F(t){s.push(t)}const h=new Set;let c=0;function M(){if(c!==0)return;const t=l;do{try{for(;c<i.length;){const n=i[c];c++,d(n),v(n.$$)}}catch(n){throw i.length=0,c=0,n}for(d(null),i.length=0,c=0;y.length;)y.pop()();for(let n=0;n<s.length;n+=1){const e=s[n];h.has(e)||(h.add(e),e())}s.length=0}while(i.length);for(;b.length;)b.pop()();p=!1,h.clear(),d(t)}function v(t){if(t.fragment!==null){t.update(),E(t.before_update);const n=t.dirty;t.dirty=[-1],t.fragment&&t.fragment.p(t.ctx,n),t.after_update.forEach(F)}}function W(t){const n=[],e=[];s.forEach(r=>t.indexOf(r)===-1?n.push(r):e.push(r)),e.forEach(r=>r()),s=n}export{w as A,K as B,G as C,I as D,J as E,H as F,d as a,Q as b,U as c,q as d,A as e,M as f,x as g,F as h,B as i,N as j,P as k,T as l,y as m,g as n,R as o,C as p,S as q,E as r,D as s,V as t,W as u,l as v,j as w,i as x,z as y,L as z};
