.modal.svelte-xd5b65.svelte-xd5b65,.modal-background.svelte-xd5b65.svelte-xd5b65{inset:0;position:absolute}.modal-close.svelte-xd5b65.svelte-xd5b65{-moz-appearance:none;-webkit-appearance:none;background-color:#0a0a0a33;border:none;border-radius:290486px;cursor:pointer;pointer-events:auto;display:inline-block;flex-grow:0;flex-shrink:0;font-size:0;height:20px;max-height:20px;max-width:20px;min-height:20px;min-width:20px;outline:none;position:relative;vertical-align:top;width:20px}.modal-close.svelte-xd5b65.svelte-xd5b65:before,.modal-close.svelte-xd5b65.svelte-xd5b65:after{background-color:#fff;content:"";display:block;left:50%;position:absolute;top:50%;transform:translate(-50%) translateY(-50%) rotate(45deg);transform-origin:center center}.modal-close.svelte-xd5b65.svelte-xd5b65:before{height:2px;width:50%}.modal-close.svelte-xd5b65.svelte-xd5b65:after{height:50%;width:2px}.modal-close.svelte-xd5b65.svelte-xd5b65:hover,.modal-close.svelte-xd5b65.svelte-xd5b65:focus{background-color:#0a0a0a4d}.modal-close.svelte-xd5b65.svelte-xd5b65:active{background-color:#0a0a0a66}.is-large.modal-close.svelte-xd5b65.svelte-xd5b65{height:32px;max-height:32px;max-width:32px;min-height:32px;min-width:32px;width:32px}.modal.svelte-xd5b65.svelte-xd5b65{align-items:center;display:none;flex-direction:column;justify-content:center;overflow:hidden;position:fixed;z-index:40}.modal.is-active.svelte-xd5b65.svelte-xd5b65{display:flex}.modal-background.svelte-xd5b65.svelte-xd5b65{background-color:#0a0a0adb}.modal-card.svelte-xd5b65.svelte-xd5b65{margin:0 20px;max-height:calc(100vh - 160px);overflow:auto;position:relative;width:100%}@media screen and (min-width: 769px),print{.modal-card.svelte-xd5b65.svelte-xd5b65{margin:0 auto;max-height:calc(100vh - 40px);width:640px}}.modal-close.svelte-xd5b65.svelte-xd5b65{background:none;height:40px;position:fixed;right:20px;top:20px;width:40px}.modal-card.svelte-xd5b65.svelte-xd5b65{display:flex;flex-direction:column;max-height:calc(100vh - 40px);overflow:hidden;overflow-y:visible;-ms-overflow-y:visible}.modal-card-head.svelte-xd5b65.svelte-xd5b65,.modal-card-foot.svelte-xd5b65.svelte-xd5b65{align-items:center;background-color:#f5f5f5;display:flex;flex-shrink:0;justify-content:flex-start;padding:20px;position:relative}.modal-card-head.svelte-xd5b65.svelte-xd5b65{border-bottom:1px solid #dbdbdb;border-top-left-radius:6px;border-top-right-radius:6px}.modal-card-title.svelte-xd5b65.svelte-xd5b65{color:#363636;flex-grow:1;flex-shrink:0;font-size:1.5rem;line-height:1}.modal-card-foot.svelte-xd5b65.svelte-xd5b65{border-bottom-left-radius:6px;border-bottom-right-radius:6px;border-top:1px solid #dbdbdb}.modal-card-foot.svelte-xd5b65 .button.svelte-xd5b65:not(:last-child){margin-right:.5em}.modal-card-body.svelte-xd5b65.svelte-xd5b65{-webkit-overflow-scrolling:touch;background-color:#fff;flex-grow:1;flex-shrink:1;overflow:auto;padding:20px}.input.svelte-1ixbxod.svelte-1ixbxod{-moz-appearance:none;-webkit-appearance:none;align-items:center;border:1px solid transparent;border-radius:4px;box-shadow:none;display:inline-flex;font-size:1rem;height:2.5em;justify-content:flex-start;line-height:1.5;padding-bottom:calc(.5em - 1px);padding-left:calc(.75em - 1px);padding-right:calc(.75em - 1px);padding-top:calc(.5em - 1px);position:relative;vertical-align:top}.input.is-rounded.svelte-1ixbxod.svelte-1ixbxod{border-radius:290486px;padding-left:calc(1.125em - 1px);padding-right:calc(1.125em - 1px)}.input.svelte-1ixbxod.svelte-1ixbxod{background-color:#fff;border-color:#dbdbdb;border-radius:4px;color:#363636}.input.svelte-1ixbxod.svelte-1ixbxod::-moz-placeholder{color:#3636364d}.input.svelte-1ixbxod.svelte-1ixbxod::-webkit-input-placeholder{color:#3636364d}.input.svelte-1ixbxod.svelte-1ixbxod:-moz-placeholder{color:#3636364d}.input.svelte-1ixbxod.svelte-1ixbxod:-ms-input-placeholder{color:#3636364d}.input.svelte-1ixbxod.svelte-1ixbxod:hover{border-color:#b5b5b5}.input.svelte-1ixbxod.svelte-1ixbxod:focus{border-color:#3273dc;box-shadow:0 0 0 .125em #3273dc40}.input.svelte-1ixbxod.svelte-1ixbxod{box-shadow:inset 0 .0625em .125em #0a0a0a0d;max-width:100%;width:100%}.tags.svelte-1ixbxod.svelte-1ixbxod{align-items:center;display:flex;flex-wrap:wrap;justify-content:flex-start}.tags.svelte-1ixbxod .tag.svelte-1ixbxod{margin-bottom:.5rem}.tags.svelte-1ixbxod .tag.svelte-1ixbxod:not(:last-child){margin-right:.5rem}.tags.svelte-1ixbxod.svelte-1ixbxod:last-child{margin-bottom:-.5rem}.tags.svelte-1ixbxod.svelte-1ixbxod:not(:last-child){margin-bottom:1rem}.tag.svelte-1ixbxod.svelte-1ixbxod:not(body){align-items:center;background-color:#f5f5f5;border-radius:4px;color:#4a4a4a;display:inline-flex;font-size:.75rem;height:2em;justify-content:center;line-height:1.5;padding-left:.75em;padding-right:.75em;white-space:nowrap}.tag:not(body).is-primary.svelte-1ixbxod.svelte-1ixbxod{background-color:#da9c20;color:#fff}
