.breadcrumb.svelte-6ensgs.svelte-6ensgs.svelte-6ensgs{font-size:1rem;white-space:nowrap;margin-bottom:1.5rem}.breadcrumb.svelte-6ensgs a.svelte-6ensgs.svelte-6ensgs{align-items:center;display:flex;justify-content:center;padding:0 .75em}.breadcrumb.svelte-6ensgs a.svelte-6ensgs.svelte-6ensgs:hover{color:#363636}.breadcrumb.svelte-6ensgs li.svelte-6ensgs.svelte-6ensgs{align-items:center;display:flex}.breadcrumb.svelte-6ensgs li:first-child a.svelte-6ensgs.svelte-6ensgs{padding-left:0}.breadcrumb.svelte-6ensgs li.is-active a.svelte-6ensgs.svelte-6ensgs{color:#363636;cursor:default;pointer-events:none}.breadcrumb.svelte-6ensgs li.svelte-6ensgs+li.svelte-6ensgs:before{color:#b5b5b5;content:"/"}.breadcrumb.svelte-6ensgs ul.svelte-6ensgs.svelte-6ensgs{align-items:flex-start;display:flex;flex-wrap:wrap;justify-content:flex-start}
